package com.ruoyi.dw.controller;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.dw.domain.CjOption;
import com.ruoyi.dw.service.ICjOptionService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 数据采集选项Controller
 * 
 * @author sunyg
 * @date 2025-06-26
 */
@RestController
@RequestMapping("/cj/option")
public class CjOptionController extends BaseController
{
    @Autowired
    private ICjOptionService cjOptionService;

    /**
     * 查询数据采集选项列表
     */
    @GetMapping("/list")
    public TableDataInfo list(CjOption cjOption)
    {
        startPage();
        List<CjOption> list = cjOptionService.selectCjOptionList(cjOption);
        return getDataTable(list);
    }

    /**
     * 导出数据采集选项列表
     */
    @Log(title = "数据采集选项", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CjOption cjOption)
    {
        List<CjOption> list = cjOptionService.selectCjOptionList(cjOption);
        ExcelUtil<CjOption> util = new ExcelUtil<CjOption>(CjOption.class);
        util.exportExcel(response, list, "数据采集选项数据");
    }

    /**
     * 获取数据采集选项详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(cjOptionService.selectCjOptionById(id));
    }

    /**
     * 新增数据采集选项
     */
    @Log(title = "数据采集选项", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CjOption cjOption)
    {
        return toAjax(cjOptionService.insertCjOption(cjOption));
    }

    /**
     * 修改数据采集选项
     */
    @Log(title = "数据采集选项", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CjOption cjOption)
    {
        return toAjax(cjOptionService.updateCjOption(cjOption));
    }

    /**
     * 删除数据采集选项
     */
    @Log(title = "数据采集选项", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(cjOptionService.deleteCjOptionByIds(ids));
    }




}
