package com.ruoyi.dw.controller;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.dw.domain.CjStudent;
import com.ruoyi.dw.service.ICjStudentService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 采集学生信息Controller
 * 
 * @author sunyg
 * @date 2025-06-26
 */
@RestController
@RequestMapping("/cj/student")
public class CjStudentController extends BaseController
{
    @Autowired
    private ICjStudentService cjStudentService;

    /**
     * 查询采集学生信息列表
     */
    @GetMapping("/list")
    public TableDataInfo list(CjStudent cjStudent)
    {
        startPage();
        List<CjStudent> list = cjStudentService.selectCjStudentList(cjStudent);
        return getDataTable(list);
    }



    /**
     * 导出采集学生信息列表
     */
    @Log(title = "采集学生信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CjStudent cjStudent)
    {
        List<CjStudent> list = cjStudentService.selectCjStudentList(cjStudent);
        ExcelUtil<CjStudent> util = new ExcelUtil<CjStudent>(CjStudent.class);
        util.exportExcel(response, list, "采集学生信息数据");
    }

    /**
     * 获取采集学生信息详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(cjStudentService.selectCjStudentById(id));
    }

    /**
     * 新增采集学生信息
     */
    @Log(title = "采集学生信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CjStudent cjStudent)
    {
        return toAjax(cjStudentService.insertCjStudent(cjStudent));
    }

    /**
     * 修改采集学生信息
     */
    @Log(title = "采集学生信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CjStudent cjStudent)
    {
        return toAjax(cjStudentService.updateCjStudent(cjStudent));
    }

    /**
     * 删除采集学生信息
     */
    @Log(title = "采集学生信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(cjStudentService.deleteCjStudentByIds(ids));
    }

    /**
     * 确认采集学生信息
     */
    @Log(title = "采集学生信息", businessType = BusinessType.DELETE)
    @PutMapping("/confirm/{ids}")
    public AjaxResult confirmStudent(@PathVariable Long[] ids) {
        return toAjax(cjStudentService.confirmCjStudent(ids));
    }
}
