package com.ruoyi.dw.controller;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.dw.domain.DwIndexConfig;
import com.ruoyi.dw.service.IDwIndexConfigService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 调查问卷统计展示Controller
 * 
 * @author sunyg
 * @date 2025-06-27
 */
@RestController
@RequestMapping("/dw/config")
public class DwIndexConfigController extends BaseController
{
    @Autowired
    private IDwIndexConfigService dwIndexConfigService;

    /**
     * 查询调查问卷统计展示列表
     */
    @GetMapping("/list")
    public TableDataInfo list(DwIndexConfig dwIndexConfig)
    {
        startPage();
        List<DwIndexConfig> list = dwIndexConfigService.selectDwIndexConfigList(dwIndexConfig);
        return getDataTable(list);
    }

    /**
     * 获取首页的数据展示
     * @return
     */
    @GetMapping("/getIndex")
    public AjaxResult getIndex(){
        return AjaxResult.success(dwIndexConfigService.getIndex());
    }

    /**
     * 导出调查问卷统计展示列表
     */
    @Log(title = "调查问卷统计展示", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DwIndexConfig dwIndexConfig)
    {
        List<DwIndexConfig> list = dwIndexConfigService.selectDwIndexConfigList(dwIndexConfig);
        ExcelUtil<DwIndexConfig> util = new ExcelUtil<DwIndexConfig>(DwIndexConfig.class);
        util.exportExcel(response, list, "调查问卷统计展示数据");
    }

    /**
     * 获取调查问卷统计展示详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(dwIndexConfigService.selectDwIndexConfigById(id));
    }

    /**
     * 新增调查问卷统计展示
     */
    @Log(title = "调查问卷统计展示", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DwIndexConfig dwIndexConfig)
    {
        if (StringUtils.isEmpty(dwIndexConfig.getQuestionId())){
            return AjaxResult.error("请先选择展示调查问题");
        }
        String[] question_ids = dwIndexConfig.getQuestionId().split(",");
        if (question_ids.length > 1 && dwIndexConfig.getIndexType() == 0){
            return AjaxResult.error("饼状图只能选择一个问题");
        }
        return toAjax(dwIndexConfigService.insertDwIndexConfig(dwIndexConfig));
    }

    /**
     * 修改调查问卷统计展示
     */
    @Log(title = "调查问卷统计展示", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DwIndexConfig dwIndexConfig)
    {
        if (StringUtils.isEmpty(dwIndexConfig.getQuestionId())){
            return AjaxResult.error("请先选择展示调查问题");
        }
        String[] question_ids = dwIndexConfig.getQuestionId().split(",");
        if (question_ids.length > 1 && dwIndexConfig.getIndexType() == 0){
            return AjaxResult.error("饼状图只能选择一个问题");
        }
        return toAjax(dwIndexConfigService.updateDwIndexConfig(dwIndexConfig));
    }

    /**
     * 删除调查问卷统计展示
     */
    @Log(title = "调查问卷统计展示", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(dwIndexConfigService.deleteDwIndexConfigByIds(ids));
    }

}
