package com.ruoyi.dw.controller;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.dw.domain.DwInfo;
import com.ruoyi.dw.service.IDwInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 调查问卷主体Controller
 * 
 * @author sunyg
 * @date 2025-06-26
 */
@RestController
@RequestMapping("/dw/info")
public class DwInfoController extends BaseController
{
    @Autowired
    private IDwInfoService dwInfoService;

    /**
     * 查询调查问卷主体列表
     */
    @GetMapping("/list")
    public TableDataInfo list(DwInfo dwInfo)
    {
        startPage();
        List<DwInfo> list = dwInfoService.selectDwInfoList(dwInfo);
        return getDataTable(list);
    }

    /**
     * 调查问卷下拉框选择
     * @return
     */
    @GetMapping("/select")
    public AjaxResult select()
    {
        List<DwInfo> list = dwInfoService.selectDwInfoList(new DwInfo());
        return AjaxResult.success(list);
    }

    /**
     * 导出调查问卷主体列表
     */
    @Log(title = "调查问卷主体", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DwInfo dwInfo)
    {
        List<DwInfo> list = dwInfoService.selectDwInfoList(dwInfo);
        ExcelUtil<DwInfo> util = new ExcelUtil<DwInfo>(DwInfo.class);
        util.exportExcel(response, list, "调查问卷主体数据");
    }

    /**
     * 获取调查问卷主体详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(dwInfoService.selectDwInfoById(id));
    }

    /**
     * 新增调查问卷主体
     */
    @Log(title = "调查问卷主体", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DwInfo dwInfo)
    {
        return toAjax(dwInfoService.insertDwInfo(dwInfo));
    }

    /**
     * 修改调查问卷主体
     */
    @Log(title = "调查问卷主体", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DwInfo dwInfo)
    {
        return toAjax(dwInfoService.updateDwInfo(dwInfo));
    }

    /**
     * 删除调查问卷主体
     */
    @Log(title = "调查问卷主体", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(dwInfoService.deleteDwInfoByIds(ids));
    }


}
