package com.ruoyi.dw.service.impl;

import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.dw.domain.vo.AnswerCountVo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.dw.mapper.DwIndexConfigMapper;
import com.ruoyi.dw.domain.DwIndexConfig;
import com.ruoyi.dw.service.IDwIndexConfigService;

/**
 * 调查问卷统计展示Service业务层处理
 * 
 * @author sunyg
 * @date 2025-06-27
 */
@Service
public class DwIndexConfigServiceImpl implements IDwIndexConfigService 
{
    @Autowired
    private DwIndexConfigMapper dwIndexConfigMapper;

    /**
     * 查询调查问卷统计展示
     * 
     * @param id 调查问卷统计展示主键
     * @return 调查问卷统计展示
     */
    @Override
    public DwIndexConfig selectDwIndexConfigById(Long id)
    {
        return dwIndexConfigMapper.selectDwIndexConfigById(id);
    }

    /**
     * 查询调查问卷统计展示列表
     * 
     * @param dwIndexConfig 调查问卷统计展示
     * @return 调查问卷统计展示
     */
    @Override
    public List<DwIndexConfig> selectDwIndexConfigList(DwIndexConfig dwIndexConfig)
    {
        return dwIndexConfigMapper.selectDwIndexConfigList(dwIndexConfig);
    }

    /**
     * 新增调查问卷统计展示
     * 
     * @param dwIndexConfig 调查问卷统计展示
     * @return 结果
     */
    @Override
    public int insertDwIndexConfig(DwIndexConfig dwIndexConfig)
    {
        dwIndexConfig.setCreateTime(DateUtils.getNowDate());
        return dwIndexConfigMapper.insertDwIndexConfig(dwIndexConfig);
    }

    /**
     * 修改调查问卷统计展示
     * 
     * @param dwIndexConfig 调查问卷统计展示
     * @return 结果
     */
    @Override
    public int updateDwIndexConfig(DwIndexConfig dwIndexConfig)
    {
        dwIndexConfig.setUpdateTime(DateUtils.getNowDate());
        return dwIndexConfigMapper.updateDwIndexConfig(dwIndexConfig);
    }

    /**
     * 批量删除调查问卷统计展示
     * 
     * @param ids 需要删除的调查问卷统计展示主键
     * @return 结果
     */
    @Override
    public int deleteDwIndexConfigByIds(Long[] ids)
    {
        return dwIndexConfigMapper.deleteDwIndexConfigByIds(ids);
    }

    /**
     * 删除调查问卷统计展示信息
     * 
     * @param id 调查问卷统计展示主键
     * @return 结果
     */
    @Override
    public int deleteDwIndexConfigById(Long id)
    {
        return dwIndexConfigMapper.deleteDwIndexConfigById(id);
    }

    @Override
    public Map<String, Object> getIndex()
    {
        List<DwIndexConfig> configs = dwIndexConfigMapper.selectDwIndexConfigList(new DwIndexConfig());
        Map<String, Object> result = new HashMap<String, Object>();
        for (DwIndexConfig config: configs){
            result.put("id", config.getId());
            result.put("indexType", config.getIndexType());
            List<AnswerCountVo> list = dwIndexConfigMapper.selectIndex(config.getQuestionId().split(","), config.getInfoId());
            result.put("data", list);
        }
        return result;
    }
}
